# Get DLRM
This [CM script](https://github.com/mlcommons/ck/blob/master/cm/docs/specs/script.md) git clones the [DLRM repository](https://github.com/facebookdresearch/dlrm).

## Commands
To install
```
cm run script --tags=get,mlperf,dlrm,src
```

## Exported Variables
* `DLRM_DIR`: Directory path of the cloned dlrm repository

## Supported and Tested OS
1. Ubuntu 18.04, 20.04, 22.04
2. RHEL 9
